"use client";
import { jsx, Fragment } from 'react/jsx-runtime';
import { useState, useRef, useEffect, useLayoutEffect } from 'react';
import ReactDOM from 'react-dom';

const PORTAL_ID = 'ix-portal';
const IxOverlay = (props) => {
    const [portalRef, setPortalRef] = useState(null);
    const resolveElementRef = useRef({});
    const viewRefs = useRef({});
    const [views, setViews] = useState({});
    useEffect(() => {
        const addOverlay = (id, view) => {
            const _views = { ...viewRefs.current };
            _views[id] = view;
            setViews(_views);
            viewRefs.current = _views;
        };
        const removeOverlay = (id) => {
            const _views = { ...viewRefs.current };
            delete _views[id];
            setViews(_views);
            viewRefs.current = _views;
        };
        props.delegate.attachViewToPortal = async (id, view) => {
            addOverlay(id, view);
            return new Promise((resolve) => {
                const r = { ...resolveElementRef.current };
                r[id] = resolve;
                resolveElementRef.current = r;
            });
        };
        props.delegate.removeViewFromPortal = async (id) => {
            removeOverlay(id);
        };
        props.delegate.portalReady();
    }, []);
    useLayoutEffect(() => {
        const portalRef = document.querySelector(`#${PORTAL_ID}`);
        if (portalRef) {
            setPortalRef(portalRef);
        }
    }, []);
    useLayoutEffect(() => {
        Object.keys(views).forEach((key) => {
            const resolveQueue = { ...resolveElementRef.current };
            const element = document.querySelector(`[data-portal-id="${key}"]`);
            if (element && element.children.length === 1 && resolveQueue[key]) {
                const view = element.children[0];
                resolveQueue[key](view);
            }
        });
    }, [views]);
    if (!portalRef) {
        return null;
    }
    return (jsx(Fragment, { children: Object.keys(views).map((key) => {
            const RenderView = views[key];
            return ReactDOM.createPortal(jsx("div", { "data-portal-id": key, style: { display: 'contents ' }, children: RenderView }), portalRef, key);
        }) }));
};

export { IxOverlay, PORTAL_ID };
//# sourceMappingURL=portal.js.map
