"use client";
import { jsx } from 'react/jsx-runtime';
import { useRef, useCallback } from 'react';
import ReactDOMClient from 'react-dom/client';
import InternalIxTree from './internal-tree.js';

const IxTree = (props) => {
    const cachedRootNodes = useRef(new Map());
    const renderItem = useCallback((_, data, __, context, update) => {
        const treeItem = document.createElement('ix-tree-item');
        treeItem.hasChildren = data.hasChildren;
        treeItem.context = context[data.id];
        update((itemData, context) => {
            treeItem.context = context[itemData.id];
            treeItem.hasChildren = itemData.hasChildren;
        });
        const container = document.createElement('DIV');
        const rootNode = ReactDOMClient.createRoot(container);
        if (props.renderItem) {
            rootNode.render(props.renderItem(data.data));
        }
        treeItem.appendChild(container);
        cachedRootNodes.current.set(treeItem, rootNode);
        return treeItem;
    }, []);
    return (jsx(InternalIxTree, { ...props, renderItem: props.renderItem ? renderItem : undefined, onNodeRemoved: (removed) => {
            const { detail } = removed;
            detail.forEach((removedItemElement) => {
                if (cachedRootNodes.current.has(removedItemElement)) {
                    cachedRootNodes.current.get(removedItemElement)?.unmount();
                    cachedRootNodes.current.delete(removedItemElement);
                }
            });
        } }));
};

export { IxTree, IxTree as default };
//# sourceMappingURL=tree.js.map
